@@ -1,9 +1,18 @@
+# frozen_string_literal: true
+
 HTML::Pipeline.require_dependency('rouge', 'SyntaxHighlightFilter')
 
 module HTML
   class Pipeline
-    # HTML Filter that syntax highlights code blocks wrapped
-    # in <pre lang="...">.
+    # HTML Filter that syntax highlights text inside code blocks.
+    #
+    # Context options:
+    #
+    #   :highlight => String represents the language to pick lexer. Defaults to empty string.
+    #   :scope => String represents the class attribute adds to pre element after.
+    #             Defaults to "highlight highlight-css" if highlights a css code block.
+    #
+    # This filter does not write any additional information to the context hash.
     class SyntaxHighlightFilter < Filter
       def initialize(*args)
         super(*args)
@@ -15,23 +24,20 @@ module HTML
           default = context[:highlight] && context[:highlight].to_s
           next unless lang = node['lang'] || default
           next unless lexer = lexer_for(lang)
-          text = node.inner_text
 
-          html = highlight_with_timeout_handling(text, lang)
+          text = node.inner_text
+          html = highlight_with_timeout_handling(text, lexer)
           next if html.nil?
 
           node.inner_html = html
-          klass = node['class']
-          scope = context[:scope] || "highlight-#{lang}"
-          klass = [klass, scope].compact.join ' '
-
-          node['class'] = klass
+          scope = context.fetch(:scope) { 'highlight' }
+          node['class'] = "#{scope} #{scope}-#{lang}"
         end
         doc
       end
 
-      def highlight_with_timeout_handling(text, lang)
-        Rouge.highlight(text, lang, @formatter)
+      def highlight_with_timeout_handling(text, lexer)
+        Rouge.highlight(text, lexer, @formatter)
       rescue Timeout::Error => _
         nil
       end
